@@ -31,7 +31,7 @@ def add_mch_skills(skill_library):
     skill_library.add_resource(
         name="GCD",
         job_resource_settings=JobResourceSettings(
-            max_value=6, skill_allowlist=("_Wildfire", "Detonator")
+            max_value=6, skill_allowlist=("Wildfire (dot)", "Detonator")
         ),
     )
 
@@ -46,7 +46,7 @@ def add_mch_skills(skill_library):
         follow_ups = {}
         for battery in range(50, 110, 10):
             skill = Skill(
-                name="Arm Punch",
+                name="Arm Punch (pet)",
                 status_effect_denylist=("Dragon Sight",),
                 damage_spec=DamageSpec(
                     potency=int((battery - 50) * slope + min_potency),
@@ -73,7 +73,7 @@ def add_mch_skills(skill_library):
         follow_up = {}
         for battery in range(50, 110, 10):
             skill = Skill(
-                name="Roller Dash",
+                name="Roller Dash (pet)",
                 status_effect_denylist=("Dragon Sight",),
                 damage_spec=DamageSpec(
                     potency=int((battery - 50) * slope + min_potency),
@@ -97,7 +97,7 @@ def add_mch_skills(skill_library):
         follow_up = {}
         for battery in range(50, 110, 10):
             skill = Skill(
-                name="Pile Bunker",
+                name="Pile Bunker (pet)",
                 status_effect_denylist=("Dragon Sight",),
                 damage_spec=DamageSpec(
                     potency=int((battery - 50) * slope + min_potency),
@@ -121,7 +121,7 @@ def add_mch_skills(skill_library):
             battery_range = 50
             slope = (max_potency - min_potency) / battery_range
             skill = Skill(
-                name="Crowned Collider",
+                name="Crowned Collider (pet)",
                 status_effect_denylist=("Dragon Sight",),
                 damage_spec=DamageSpec(
                     potency=int((battery - 50) * slope + min_potency),
@@ -139,7 +139,7 @@ def add_mch_skills(skill_library):
 
     def get_flamethrower_follow_ups():
         flamethrower_dot = Skill(
-            name="_Flamethrower dot",
+            name="Flamethrower (dot)",
             damage_spec=DamageSpec(potency=80, damage_class=DamageClass.PHYSICAL_DOT),
         )
         follow_ups = {}
@@ -215,7 +215,7 @@ def add_mch_skills(skill_library):
         )
     wildfire_damage_spec[SimConsts.DEFAULT_CONDITION] = DamageSpec(potency=0)
     wildfire_skill = Skill(
-        name="_Wildfire",
+        name="Wildfire (dot)",
         is_GCD=False,
         job_resources_snapshot=False,
         damage_spec=wildfire_damage_spec,
@@ -227,12 +227,6 @@ def add_mch_skills(skill_library):
         snapshot_debuffs_with_parent=True,
         delay_after_parent_application=10 * 1000,
     )
-    detonator_follow_up = FollowUp(
-        skill=wildfire_skill,
-        snapshot_buffs_with_parent=True,
-        snapshot_debuffs_with_parent=True,
-        delay_after_parent_application=0,
-    )
 
     skill_library.add_skill(
         Skill(
@@ -423,7 +417,7 @@ def add_mch_skills(skill_library):
         )
     )
     bioblaster_dot = Skill(
-        name="_Bioblaster dot",
+        name="Bioblaster (dot)",
         is_GCD=False,
         damage_spec=DamageSpec(potency=50, damage_class=DamageClass.PHYSICAL_DOT),
     )
