@@ -39,87 +39,42 @@ def add_nin_skills(skill_library):
     # TODO: this is bugged. We are setting delay_after_parent_application=88 and
     # not snapshotting with parent to mimic the 0.088s snapshot delay on anything
     # bunshin. This in return ignores when the damage actually comes out.
-    bunshin_melee_follow_up_ = FollowUp(
-        skill=Skill(
-            name="_Bunshin_melee",
-            is_GCD=False,
-            damage_spec=DamageSpec(
-                potency=160, damage_class=DamageClass.PET, pet_job_mod_override=100
+    BUNSHIN_MELEE_POTENCY = 160
+    BUNSHIN_RANGED_POTENCY = 160
+    BUNSHIN_AREA_POTENCY = 80
+    bunshin_follow_ups = [
+        ("Spinning Edge", BUNSHIN_MELEE_POTENCY),
+        ("Gust Slash", BUNSHIN_MELEE_POTENCY),
+        ("Aeolian Edge", BUNSHIN_MELEE_POTENCY),
+        ("Armor Crush", BUNSHIN_MELEE_POTENCY),
+        ("Forked Raiju", BUNSHIN_MELEE_POTENCY),
+        ("Fleeting Raiju", BUNSHIN_MELEE_POTENCY),
+        ("Throwing Dagger", BUNSHIN_RANGED_POTENCY),
+        ("Hakke Mujinsatsu", BUNSHIN_AREA_POTENCY),
+        ("Death Blossom", BUNSHIN_AREA_POTENCY),
+    ]
+    all_bunshin_follow_ups = {}
+    for sk, bunshin_potency in bunshin_follow_ups:
+        all_bunshin_follow_ups[sk] = FollowUp(
+            skill=Skill(
+                name=f"{sk} (pet)",
+                is_GCD=False,
+                damage_spec=DamageSpec(
+                    potency=bunshin_potency,
+                    damage_class=DamageClass.PET,
+                    pet_job_mod_override=100,
+                ),
+                status_effect_denylist=("Dragon Sight",),
             ),
-        ),
-        delay_after_parent_application=88,
-        snapshot_buffs_with_parent=False,
-        snapshot_debuffs_with_parent=False,
-    )
-    bunshin_ranged_follow_up_ = FollowUp(
-        skill=Skill(
-            name="_Bunshin_ranged",
-            is_GCD=False,
-            damage_spec=DamageSpec(
-                potency=160, damage_class=DamageClass.PET, pet_job_mod_override=100
-            ),
-        ),
-        delay_after_parent_application=88,
-        snapshot_buffs_with_parent=False,
-        snapshot_debuffs_with_parent=False,
-    )
-    bunshin_area_follow_up_ = FollowUp(
-        skill=Skill(
-            name="_Bunshin_area",
-            is_GCD=False,
-            damage_spec=DamageSpec(
-                potency=80, damage_class=DamageClass.PET, pet_job_mod_override=100
-            ),
-        ),
-        delay_after_parent_application=88,
-        snapshot_buffs_with_parent=False,
-        snapshot_debuffs_with_parent=False,
-    )
+            delay_after_parent_application=88,
+            snapshot_buffs_with_parent=False,
+            snapshot_debuffs_with_parent=False,
+        )
 
-    _huton_follow_up_huton = FollowUp(
-        skill=Skill(
-            name="_Huton buff",
-            is_GCD=False,
-            buff_spec=StatusEffectSpec(
-                haste_time_reduction=0.15,
-                auto_attack_delay_reduction=0.15,
-                duration=60 * 1000,
-                max_duration=60 * 1000,
-            ),
-        ),
-        delay_after_parent_application=0,
-    )
-
-    _huton_follow_up_hakke = FollowUp(
-        skill=Skill(
-            name="_Huton buff",
-            is_GCD=False,
-            buff_spec=StatusEffectSpec(
-                haste_time_reduction=0.15,
-                auto_attack_delay_reduction=0.15,
-                duration=10 * 1000,
-                max_duration=60 * 1000,
-            ),
-        ),
-        delay_after_parent_application=0,
-    )
-    _huton_follow_up_armor_crush = FollowUp(
-        skill=Skill(
-            name="_Huton buff",
-            is_GCD=False,
-            buff_spec=StatusEffectSpec(
-                haste_time_reduction=0.15,
-                auto_attack_delay_reduction=0.15,
-                duration=30 * 1000,
-                max_duration=60 * 1000,
-            ),
-        ),
-        delay_after_parent_application=0,
-    )
     _dream_follow_ups = (
         FollowUp(
             skill=Skill(
-                name="_dream_within_a_dream1",
+                name="Dream Within a Dream",
                 is_GCD=False,
                 damage_spec=DamageSpec(150),
             ),
@@ -129,7 +84,7 @@ def add_nin_skills(skill_library):
         ),
         FollowUp(
             skill=Skill(
-                name="_dream_within_a_dream2",
+                name="Dream Within a Dream",
                 is_GCD=False,
                 damage_spec=DamageSpec(150),
             ),
@@ -139,7 +94,7 @@ def add_nin_skills(skill_library):
         ),
         FollowUp(
             skill=Skill(
-                name="_dream_within_a_dream3",
+                name="Dream Within a Dream",
                 is_GCD=False,
                 damage_spec=DamageSpec(150),
             ),
@@ -201,7 +156,7 @@ def add_nin_skills(skill_library):
             ),
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: (spinning_edge_follow_up,),
-                "Bunshin": (bunshin_melee_follow_up_, spinning_edge_follow_up),
+                "Bunshin": (all_bunshin_follow_ups['Spinning Edge'], spinning_edge_follow_up),
             },
         )
     )
@@ -225,9 +180,9 @@ def add_nin_skills(skill_library):
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: (gust_slash_damage_follow_up,),
                 "No Combo": (gust_slash_damage_no_combo_follow_up,),
-                "Bunshin": (bunshin_melee_follow_up_, gust_slash_damage_follow_up),
+                "Bunshin": (all_bunshin_follow_ups['Gust Slash'], gust_slash_damage_follow_up),
                 "Bunshin, No Combo": (
-                    bunshin_melee_follow_up_,
+                    all_bunshin_follow_ups['Gust Slash'],
                     gust_slash_damage_no_combo_follow_up,
                 ),
             },
@@ -247,7 +202,7 @@ def add_nin_skills(skill_library):
             ),
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: (throwing_dagger_follow_up,),
-                "Bunshin": (throwing_dagger_follow_up, bunshin_ranged_follow_up_),
+                "Bunshin": (throwing_dagger_follow_up, all_bunshin_follow_ups['Throwing Dagger']),
             },
         )
     )
@@ -300,18 +255,18 @@ def add_nin_skills(skill_library):
                 "No Combo": (aeolian_edge_no_combo_follow_up,),
                 "No Positional": (aeolian_edge_no_pos_follow_up,),
                 "No Combo, No Positional": (aeolian_edge_no_pos_no_combo_follow_up,),
-                "Bunshin": (aeolian_edge_follow_up, bunshin_melee_follow_up_),
+                "Bunshin": (aeolian_edge_follow_up, all_bunshin_follow_ups['Aeolian Edge']),
                 "Bunshin, No Combo": (
                     aeolian_edge_no_combo_follow_up,
-                    bunshin_melee_follow_up_,
+                    all_bunshin_follow_ups['Aeolian Edge'],
                 ),
                 "Bunshin, No Positional": (
                     aeolian_edge_no_pos_follow_up,
-                    bunshin_melee_follow_up_,
+                    all_bunshin_follow_ups['Aeolian Edge'],
                 ),
                 "Bunshin, No Combo, No Positional": (
                     aeolian_edge_no_pos_no_combo_follow_up,
-                    bunshin_melee_follow_up_,
+                    all_bunshin_follow_ups['Aeolian Edge'],
                 ),
                 #
                 "Kazematoi": (aeolian_edge_follow_up_kaz,),
@@ -322,19 +277,19 @@ def add_nin_skills(skill_library):
                 ),
                 "Bunshin, Kazematoi": (
                     aeolian_edge_follow_up_kaz,
-                    bunshin_melee_follow_up_,
+                    all_bunshin_follow_ups['Aeolian Edge'],
                 ),
                 "Bunshin, Kazematoi, No Combo": (
                     aeolian_edge_no_combo_follow_up_kaz,
-                    bunshin_melee_follow_up_,
+                    all_bunshin_follow_ups['Aeolian Edge'],
                 ),
                 "Bunshin, Kazematoi, No Positional": (
                     aeolian_edge_no_pos_follow_up_kaz,
-                    bunshin_melee_follow_up_,
+                    all_bunshin_follow_ups['Aeolian Edge'],
                 ),
                 "Bunshin, Kazematoi, No Combo, No Positional": (
                     aeolian_edge_no_pos_no_combo_follow_up_kaz,
-                    bunshin_melee_follow_up_,
+                    all_bunshin_follow_ups['Aeolian Edge'],
                 ),
             },
         )
@@ -363,7 +318,7 @@ def add_nin_skills(skill_library):
             ),
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: (death_blossom_follow_up,),
-                "Bunshin": (bunshin_area_follow_up_, death_blossom_follow_up),
+                "Bunshin": (all_bunshin_follow_ups['Death Blossom'], death_blossom_follow_up),
             },
         )
     )
@@ -389,11 +344,11 @@ def add_nin_skills(skill_library):
                 SimConsts.DEFAULT_CONDITION: (hakke_follow_up,),
                 "No Combo": (hakke_no_combo_follow_up,),
                 "Bunshin": (
-                    bunshin_area_follow_up_,
+                    all_bunshin_follow_ups['Hakke Mujinsatsu'],
                     hakke_follow_up,
                 ),
                 "Bunshin, No Combo": (
-                    bunshin_area_follow_up_,
+                    all_bunshin_follow_ups['Hakke Mujinsatsu'],
                     hakke_no_combo_follow_up,
                 ),
             },
@@ -432,19 +387,19 @@ def add_nin_skills(skill_library):
                 "No Combo, No Positional": (armor_crush_no_pos_no_combo_follow_up,),
                 "Bunshin": (
                     armor_crush_follow_up,
-                    bunshin_melee_follow_up_,
+                    all_bunshin_follow_ups['Armor Crush'],
                 ),
                 "Bunshin, No Combo": (
                     armor_crush_no_combo_follow_up,
-                    bunshin_melee_follow_up_,
+                    all_bunshin_follow_ups['Armor Crush'],
                 ),
                 "Bunshin, No Positional": (
                     armor_crush_no_pos_follow_up,
-                    bunshin_melee_follow_up_,
+                    all_bunshin_follow_ups['Armor Crush'],
                 ),
                 "Bunshin, No Combo, No Positional": (
                     armor_crush_no_pos_no_combo_follow_up,
-                    bunshin_melee_follow_up_,
+                    all_bunshin_follow_ups['Armor Crush'],
                 ),
             },
         )
@@ -472,7 +427,7 @@ def add_nin_skills(skill_library):
 
     dokumori_debuff_follow_up = FollowUp(
         skill=Skill(
-            name="Dokumori (Debuff)",
+            name="Dokumori",
             debuff_spec=StatusEffectSpec(
                 damage_mult=1.05, duration=int(20.77 * 1000), is_party_effect=True
             ),
@@ -513,15 +468,21 @@ def add_nin_skills(skill_library):
             ),
         )
     )
+    phantom_follow_up_damage = FollowUp(skill=Skill(
+        name="Phantom Kamaitachi (pet)",
+        damage_spec=DamageSpec(
+            potency=600, damage_class=DamageClass.PET, pet_job_mod_override=100
+        )),
+        delay_after_parent_application=1560,
+        snapshot_buffs_with_parent=True,
+        snapshot_debuffs_with_parent=True    
+    )
     skill_library.add_skill(
         Skill(
             name="Phantom Kamaitachi",
             is_GCD=True,
-            damage_spec=DamageSpec(
-                potency=600, damage_class=DamageClass.PET, pet_job_mod_override=100
-            ),
             timing_spec=TimingSpec(base_cast_time=0, application_delay=1560),
-            follow_up_skills=tuple(),
+            follow_up_skills=(phantom_follow_up_damage,),
         )
     )
     skill_library.add_skill(
@@ -544,10 +505,11 @@ def add_nin_skills(skill_library):
             ),
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: tuple(),
-                "Bunshin": (bunshin_melee_follow_up_,),
+                "Bunshin": (all_bunshin_follow_ups['Forked Raiju'],),
             },
         )
     )
+    
     skill_library.add_skill(
         Skill(
             name="Fleeting Raiju",
@@ -558,7 +520,7 @@ def add_nin_skills(skill_library):
             ),
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: tuple(),
-                "Bunshin": (bunshin_melee_follow_up_,),
+                "Bunshin": (all_bunshin_follow_ups['Fleeting Raiju'],),
             },
         )
     )
@@ -826,7 +788,7 @@ def add_nin_skills(skill_library):
     )
     kunai_debuff_follow_up = FollowUp(
         skill=Skill(
-            name="Kunai's Bane (Debuff)",
+            name="Kunai's Bane",
             debuff_spec=StatusEffectSpec(damage_mult=1.10, duration=int(15.77 * 1000)),
         ),
         delay_after_parent_application=0,
