@@ -1,13 +1,13 @@
-from simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
-from simulator.skills.skill_modifier import SkillModifier
-from simulator.sim_consts import SimConsts
-from simulator.stats import Stats
-from simulator.timeline_builders.damage_builder import DamageBuilder
-from simulator.timeline_builders.snapshot_and_application_events import SnapshotAndApplicationEvents
-from simulator.testing.test_class import TestClass
-from simulator.testing.create_test_skill_library import create_test_skill_library
-from simulator.trackers.status_effects import StatusEffects
-from simulator.utils import Utils
+from ama_xiv_combat_sim.simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
+from ama_xiv_combat_sim.simulator.skills.skill_modifier import SkillModifier
+from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
+from ama_xiv_combat_sim.simulator.stats import Stats
+from ama_xiv_combat_sim.simulator.timeline_builders.damage_builder import DamageBuilder
+from ama_xiv_combat_sim.simulator.timeline_builders.snapshot_and_application_events import SnapshotAndApplicationEvents
+from ama_xiv_combat_sim.simulator.testing.test_class import TestClass
+from ama_xiv_combat_sim.simulator.testing.create_test_skill_library import create_test_skill_library
+from ama_xiv_combat_sim.simulator.trackers.status_effects import StatusEffects
+from ama_xiv_combat_sim.simulator.utils import Utils
 
 class TestDamageBuilder(TestClass):
   def __init__(self):
